#' priorPERisk:
#' Calculate  the prior risk of pre-eclampsia based on maternal characteristics.
#' @param data: A data frame with the following columns:
#'
#'
#'     Weight: Maternal weight (kg)
#'
#'     Nulliparity: 1 for nulliparous mothers and 0 for multiparous
#'
#'     CHTN: 1 for chronic hypertensive mother and 0 otherwise
#'
#'     PEHistory: 1 if there is a history of preeclampsia and 0 otherwise
#'
#'
#'
#'
#' @return The input data frame with  an additional column for the prior risk of preeclampsia.
#' @description   This function calculates the prior risk of preeclampsia.
#' @examples
#'
#' @references
#'
#' Contact: Adi Laurentiu Tarca <atarca@med.wayne.edu>
#'
#' @export
#'
priorPERisk<-function(data)

{

  data$mid = paste0("m", seq(1, nrow(data)))
  rownames(data) = data$mid
  origdata = data


  if(any(!c("Weight","PEHistory","CHTN","Nulliparity") %in% colnames(data)))
  {
    stop("Missing columns")

  }

  ano=data.frame(data[,c("Weight","PEHistory","CHTN","Nulliparity")],stringsAsFactors = F)
  ano[]=lapply(ano, function(x){as.numeric(as.character(x))})




  ano$mwkg<-ano$Weight-75
  ano$Nuli<- ano$Nulliparity
  ano$HistPe<- ano$PEHistory


prcoef<- c(-3.457168689,  1.147664941,  0.005816879,  0.773210518,  1.052614431, -0.790968378)
names(prcoef) <- c("(Intercept)","CHTN","mwkg","Nuli","HistPe","CHTN:Nuli")

makeX = function(cof, ano) {
  for (n in rownames(cof)) {
    if (n == "(Intercept)") {
      X = rep(1, dim(ano)[1])
    }
    if (n %in% names(ano)) {
      X = cbind(X, ano[, n])
    }
    if (grepl(":", n)) {
      v1 = unlist(strsplit(n, split = ":"))[1]
      v2 = unlist(strsplit(n, split = ":"))[2]
      X = cbind(X, ano[, v1] * ano[, v2])
    }
  }
  X
}


cof= as.data.frame((prcoef))

cof[]=lapply(cof, function(x){as.numeric(as.character(x))})
cof=as.matrix(cof)
rownames(cof)= names(prcoef)

pmat = makeX(cof, ano = ano)
qua = pmat %*% cof
ano$LogPriorRisk = as.numeric(as.character(qua))

ano$PriorRisk =exp(ano$LogPriorRisk)

origdata[rownames(ano),"LogPriorRisk"]=ano$LogPriorRisk

origdata[rownames(ano),"PriorRisk"]=ano$PriorRisk

rownames(origdata)<- NULL
origdata$mid<-NULL
return(origdata)
}



